@@ -2,6 +2,114 @@
 
 use strict;
 
+=head1 NAME
+
+LittleORM - ORM for Perl with Moose.
+
+=head1 VERSION
+
+Version 0.08
+
+=cut
+
+=head1 SYNOPSIS
+
+Please refer to L<LittleORM::Tutorial> for thorough description of LittleORM.
+
+=cut
+
+=head1 AUTHOR
+
+Eugene Kuzin, C<< <eugenek at 45-98.org> >>, JID: C<< <gnudist at jabber.ru> >>
+with significant contributions by
+Kain Winterheart, C<< < kain.winterheart at gmail.com> >>
+
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-littleorm at
+rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=LittleORM>.  I will
+be notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc LittleORM
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=LittleORM>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/LittleORM>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/LittleORM>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/LittleORM/>
+
+=back
+
+
+=head1 ACKNOWLEDGEMENTS
+
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2013 Eugene Kuzin.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of the the Artistic License (2.0). You may obtain a
+copy of the full license at:
+
+L<http://www.perlfoundation.org/artistic_license_2_0>
+
+Any use, modification, and distribution of the Standard or Modified
+Versions is governed by this Artistic License. By using, modifying or
+distributing the Package, you accept this license. Do not use, modify,
+or distribute the Package, if you do not accept this license.
+
+If your Modified Version has been derived from a Modified Version made
+by someone other than you, you are nevertheless required to ensure that
+your Modified Version complies with the requirements of this license.
+
+This license does not grant you the right to use any trademark, service
+mark, tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge
+patent license to make, have made, use, offer to sell, sell, import and
+otherwise transfer the Package with respect to any patent claims
+licensable by the Copyright Holder that are necessarily infringed by the
+Package. If you institute patent litigation (including a cross-claim or
+counterclaim) against any party alleging that the Package constitutes
+direct or contributory patent infringement, then this Artistic License
+to you shall terminate on the date that such litigation is filed.
+
+Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
+AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
+THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
+YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
+CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
+EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+
+=cut
+
+
 package LittleORM::Model;
 
 # Extend LittleORM::Model capabilities with filter support:
@@ -315,21 +423,25 @@ sub connect_filter_exists
 
 	{
 
-		my %select_from_sql_part = $exf -> all_tables_used_in_filter();
+		my $select_from_sql_part = '';
 
-		# {
-		# 	my %t = $exf -> all_tables_used_in_filter();
-		# 	# do not include outer table inside EXISTS select:
+		{
+			my %t = $exf -> all_tables_used_in_filter();
+			# do not include outer table inside EXISTS select:
+			$select_from_sql_part = join( ',', map { $t{ $_ } .
+								 " " .
+								 $_ }
+						           grep { $_ ne $self -> table_alias() }
+						           keys %t );
 
-		# 	%select_from_sql_part = map { $_ => $t{ $_ } } grep { $_ ne $self -> table_alias() } keys %t;
-		# }
+		}
 
-		my $sql = sprintf( " %s (SELECT 1 FROM [__ORM_USED_TABLES__] WHERE %s LIMIT 1) ",
+		my $sql = sprintf( " %s (SELECT 1 FROM %s WHERE %s LIMIT 1) ",
 				   $exists_keyword,
+				   $select_from_sql_part,
 				   join( ' AND ', $exf -> translate_into_sql_clauses() ) );
 		
 		my $c1 = $self -> model() -> clause( cond => [ _where => $sql ],
-						     included_tables => \%select_from_sql_part,
 						     table_alias => $self -> table_alias() );
 		
 		
@@ -416,20 +528,15 @@ sub translate_into_sql_clauses
 	my $clauses_number = scalar @{ $self -> clauses() };
 
 	my @all_clauses_together = ();
-	my %all = $self -> all_tables_used_in_filter();
 
 	for( my $i = 0; $i < $clauses_number; $i ++ )
 	{
 		my $clause = $self -> clauses() -> [ $i ];
 
-		push @all_clauses_together, $clause -> sql( @args,
-							    _already_used => \%all );
+		push @all_clauses_together, $clause -> sql( @args );
 
 	}
 
-	# print Carp::longmess();
-	# print Data::Dumper::Dumper( \@all_clauses_together );
-
 	return @all_clauses_together;
 }
 
