@@ -1,3 +1,112 @@
+
+=head1 NAME
+
+LittleORM - ORM for Perl with Moose.
+
+=head1 VERSION
+
+Version 0.08
+
+=cut
+
+=head1 SYNOPSIS
+
+Please refer to L<LittleORM::Tutorial> for thorough description of LittleORM.
+
+=cut
+
+=head1 AUTHOR
+
+Eugene Kuzin, C<< <eugenek at 45-98.org> >>, JID: C<< <gnudist at jabber.ru> >>
+with significant contributions by
+Kain Winterheart, C<< < kain.winterheart at gmail.com> >>
+
+
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-littleorm at
+rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=LittleORM>.  I will
+be notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc LittleORM
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=LittleORM>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/LittleORM>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/LittleORM>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/LittleORM/>
+
+=back
+
+
+=head1 ACKNOWLEDGEMENTS
+
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2013 Eugene Kuzin.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of the the Artistic License (2.0). You may obtain a
+copy of the full license at:
+
+L<http://www.perlfoundation.org/artistic_license_2_0>
+
+Any use, modification, and distribution of the Standard or Modified
+Versions is governed by this Artistic License. By using, modifying or
+distributing the Package, you accept this license. Do not use, modify,
+or distribute the Package, if you do not accept this license.
+
+If your Modified Version has been derived from a Modified Version made
+by someone other than you, you are nevertheless required to ensure that
+your Modified Version complies with the requirements of this license.
+
+This license does not grant you the right to use any trademark, service
+mark, tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge
+patent license to make, have made, use, offer to sell, sell, import and
+otherwise transfer the Package with respect to any patent claims
+licensable by the Copyright Holder that are necessarily infringed by the
+Package. If you institute patent litigation (including a cross-claim or
+counterclaim) against any party alleging that the Package constitutes
+direct or contributory patent infringement, then this Artistic License
+to you shall terminate on the date that such litigation is filed.
+
+Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
+AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
+THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
+YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
+CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
+EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+
+=cut
+
+
 use LittleORM::Db;
 use LittleORM::Db::Field;
 
@@ -564,6 +673,12 @@ sub BUILD
 {
 	my $self = shift;
 
+	if( $self -> meta() -> can( 'found_orm' ) and $self -> meta() -> found_orm() )
+	{
+		return;
+	}
+
+
 FXOINoqUOvIG1kAG:
 	foreach my $attr ( $self -> meta() -> get_all_attributes() )
 	{
@@ -1111,9 +1226,12 @@ fhFwaEknUtY5xwNr:
 						      $dbh );
 			} else
 			{
-				my @values = map { &__prep_value_for_db( $class_attr, $_ ) } @{ $val };
-				$val = sprintf( 'ANY(%s)', &ORM::Db::dbq( \@values, $dbh ) );
+				# $op = 'IN';
+				# $val = sprintf( '(%s)', join( ',', map { &LittleORM::Db::dbq( &__prep_value_for_db( $class_attr, $_ ),
+				# 							$dbh ) } @{ $val } ) );
 
+				my @values = map { &__prep_value_for_db( $class_attr, $_ ) } @{ $val };
+				$val = sprintf( 'ANY(%s)', &LittleORM::Db::dbq( \@values, $dbh ) );
 			}
 
 		} else
